@@ -5,10 +5,12 @@ use warnings;
 use Stenciller::Standard;
 use Stenciller::Stencil;
 # PODNAME: Stenciller
-our $VERSION = '0.1004'; # VERSION
-# ABSTRACT: Convert textfiles to different output
+# VERSION
+# ABSTRACT: Transforms textfiles to different output
 
-class Stenciller using Moose {
+class Stenciller using Moose with Stenciller::Utils {
+
+    use Carp 'croak';
 
     has filepath => (
         is => 'ro',
@@ -35,6 +37,7 @@ class Stenciller using Moose {
             all_stencils => 'elements',
             get_stencil => 'get',
             count_stencils => 'count',
+            has_stencils => 'count',
         },
     );
     has header_lines => (
@@ -65,19 +68,23 @@ class Stenciller using Moose {
     method BUILD {
         $self->parse;
     }
+    around has_stencils($next: $self) {
+        my $count = $self->$next;
+        return !!$count || 0;
+    }
 
-    method render(Str $plugin_name       does doc('Plugin to render contents with.'),
-                      @constructor_args  does doc('Constructor arguments for the plugin.')
-              --> Str                    does doc('Returns the rendered contents.')
+    method transform(Str $plugin_name         does doc('Plugin to read contents with.'),
+                         @constructor_args    does doc('Constructor arguments for the plugin.')
+                 --> Str                      does doc('Returns the transformed contents.')
     ) {
 
         my $plugin_class = "Stenciller::Plugin::$plugin_name";
-        eval "use $plugin_class";
+        $self->eval("use $plugin_class");
         die ("Cant 'use $plugin_class': $@") if $@;
-     #   if(!$plugin_class->does('Stenciller::Renderer')) {
-     #       croak("[$plugin_name] doesn't do the Stenciller::Renderer role. Quitting.");
-     #   }
-        return $plugin_class->new(stenciller => $self, @constructor_args)->render;
+        if(!$plugin_class->does('Stenciller::Transformer')) {
+            croak("[$plugin_name] doesn't do the Stenciller::Transformer role. Quitting.");
+        }
+        return $plugin_class->new(stenciller => $self, @constructor_args)->transform;
     }
 
     method parse {
@@ -101,7 +108,7 @@ class Stenciller using Moose {
             if(any { $environment eq $_ } (qw/header next_stencil/)) {
                 $self->add_header_line($line) and next LINE if $line !~ $stencil_start;
 
-                my $settings = $1 ? $self->eval($1) : {};
+                my $settings = $1 ? $self->eval_to_hashref($1, $self->filepath) : {};
 
                 $stencil = Stenciller::Stencil->new(
                             name => exists $settings->{'name'} ? delete $settings->{'name'} : $self->filepath->basename . "-$line_count",
@@ -138,8 +145,8 @@ class Stenciller using Moose {
         $self->handle_completed_stencil($stencil);
     }
 
-    method handle_completed_stencil(Stencil $stencil) {
-        return if !defined $stencil;
+    method handle_completed_stencil(Maybe[Stencil] $stencil) {
+        return if !Stencil->check($stencil);
         return if $stencil->skip;
         return if !$stencil->has_input  && $self->skip_if_input_empty;
         return if !$stencil->has_output && $self->skip_if_output_empty;
@@ -155,11 +162,6 @@ class Stenciller using Moose {
         }
     }
 
-    method eval(Str $possible_hash --> HashRef) {
-        my $stencil_settings = eval $possible_hash;
-        die sprintf "Can't parse stencil start: <%s> in %s: %s", $possible_hash, $self->filepath, $@ if $@;
-        return $stencil_settings;
-    }
 }
 
 __END__
@@ -170,17 +172,17 @@ __END__
 
 =head1 NAME
 
-Stenciller - Convert textfiles to different output
+Stenciller - Transforms textfiles to different output
 
 =head1 VERSION
 
-Version 0.1004, released 2015-01-15.
+Version 0.1005, released 2015-01-16.
 
 =head1 SYNOPSIS
 
     use Stenciller;
     my $stenciller = Stenciller->new(filepath => 't/corpus/test-1.stencil');
-    my $content = $stenciller->render('ToUnparsedText');
+    my $content = $stenciller->transforme('ToUnparsedText');
 
 =head1 DESCRIPTION
 
@@ -306,49 +308,9 @@ there is a header before the first stencil.
 
 =head1 METHODS
 
-
-=head2 render
-
-=begin HTML
-
-<p></p>
-
-<table style="margin-bottom: 10px; margin-left: 10px; border-collapse: bollapse;" cellpadding="0" cellspacing="0">
-<tr style="vertical-align: top;"><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">Positional parameters</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td></tr>
-<tr style="vertical-align: top;">
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>$plugin_name</code>
-
-</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
-
-</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">required</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
-<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Plugin to render contents with.<br /></td>
-</tr>
-<tr style="vertical-align: top;">
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>@constructor_args</code>
-
-</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"></td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">required</td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">slurpy</td>
-<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Constructor arguments for the plugin.<br /></td>
-</tr>
-<tr style="vertical-align: top;"><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">Returns</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #e8e8ee;">&#160;</td></tr>
-<tr style="vertical-align: top;">
-<td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a>
-
-</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td><td style="vertical-align: top; border-right: 1px solid #eee;  padding: 3px 6px; border-bottom: 1px solid #eee;">&#160;</td>
-<td style="padding: 3px 6px; vertical-align: top;  border-bottom: 1px solid #eee;">Returns the rendered contents.</td>
-</tr>
-</table>
-
-=end HTML
-
 =head1 PLUGINS
 
-The actual rendering is done by plugins. There are two plugins bundled in this distribution:
+The actual transforming is done by plugins. There are two plugins bundled in this distribution:
 
 =over 4
 
@@ -362,7 +324,7 @@ L<Stenciller::Plugin::ToHtmlPreBlock>
 
 =back
 
-Custom plugins should be in the L<Stenciller::Plugin> namespace and consume the L<Stenciller::Renderer> role.
+Custom plugins should be in the L<Stenciller::Plugin> namespace and consume the L<Stenciller::Transformer> role.
 
 =head1 SOURCE
 
