@@ -1,30 +1,24 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1004'; # VERSION
-# ABSTRACT: A plugin that renders to html
+# VERSION
+# ABSTRACT: A plugin that transforms to html
 # PODNAME: Stenciller::Plugin::ToHtmlPreBlock
 
-class Stenciller::Plugin::ToHtmlPreBlock using Moose with Stenciller::Renderer {
+class Stenciller::Plugin::ToHtmlPreBlock using Moose with Stenciller::Transformer {
 
     use HTML::Entities 'encode_entities';
 
-    has stenciller => (
-        is => 'ro',
-        isa => Stenciller,
-        required => 1,
-    );
-
-    method render {
-        my @out = ();
+    method transform {
+        my @out = ($self->stenciller->all_header_lines);
 
         STENCIL:
         foreach my $stencil ($self->stenciller->all_stencils) {
 
-            push @out => $self->normal($stencil->all_before_input);
-            push @out => $self->pre($stencil->all_input);
-            push @out => $self->normal($stencil->all_between);
-            push @out => $self->pre($stencil->all_output);
-            push @out => $self->normal($stencil->all_after_output);
+            push @out => $self->normal($stencil->all_before_input),
+                         $self->pre($stencil->all_input),
+                         $self->normal($stencil->all_between),
+                         $self->pre($stencil->all_output),
+                         $self->normal($stencil->all_after_output);
 
         }
         return join '' => @out;
@@ -53,17 +47,17 @@ __END__
 
 =head1 NAME
 
-Stenciller::Plugin::ToHtmlPreBlock - A plugin that renders to html
+Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
 
 =head1 VERSION
 
-Version 0.1004, released 2015-01-15.
+Version 0.1005, released 2015-01-16.
 
 =head1 SYNOPSIS
 
     use Stenciller;
     my $stenciller = Stenciller->new(filepath => 't/corpus/test-1.stencil');
-    my $content = $stenciller->render('ToHtmlPreBlock');
+    my $content = $stenciller->transforme('ToHtmlPreBlock');
 
 =head1 DESCRIPTION
 
