@@ -1,21 +1,21 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1004'; # VERSION
-# ABSTRACT: A plugin that just renders all the text
+# VERSION
+# ABSTRACT: A plugin that doesn't transforme the text the text
 # PODNAME: Stenciller::Plugin::ToUnparsedText
 
-class Stenciller::Plugin::ToUnparsedText using Moose with Stenciller::Renderer {
+class Stenciller::Plugin::ToUnparsedText using Moose with Stenciller::Transformer {
 
-    method render {
-        my @out = ();
+    method transform {
+        my @out = ($self->stenciller->all_header_lines);
 
         STENCIL:
         foreach my $stencil ($self->stenciller->all_stencils) {
-            push @out => $stencil->all_before_input;
-            push @out => $stencil->all_input;
-            push @out => $stencil->all_between;
-            push @out => $stencil->all_output;
-            push @out => $stencil->all_after_output;
+            push @out => $stencil->all_before_input,
+                         $stencil->all_input,
+                         $stencil->all_between,
+                         $stencil->all_output,
+                         $stencil->all_after_output;
         }
         return join "\n" => @out;
     }
@@ -31,17 +31,17 @@ __END__
 
 =head1 NAME
 
-Stenciller::Plugin::ToUnparsedText - A plugin that just renders all the text
+Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transforme the text the text
 
 =head1 VERSION
 
-Version 0.1004, released 2015-01-15.
+Version 0.1005, released 2015-01-16.
 
 =head1 SYNOPSIS
 
     use Stenciller;
     my $stenciller = Stenciller->new(filepath => 't/corpus/test-1.stencil');
-    my $content = $stenciller->render('ToUnparsedText');
+    my $content = $stenciller->transforme('ToUnparsedText');
 
 =head1 DESCRIPTION
 
