@@ -1,18 +1,13 @@
 use Stenciller::Standard;
 
-our $VERSION = '0.1004'; # VERSION
-# ABSTRACT: A role for plugins to consume
+# VERSION
+# ABSTRACT: A role for transformer plugins to consume
 # PODNAME: Stenciller::Renderer
 
 role Stenciller::Renderer using Moose {
 
     requires 'render';
 
-    has stenciller => (
-        is => 'ro',
-        isa => Stenciller,
-        required => 1,
-    );
 }
 
 1;
@@ -25,15 +20,15 @@ __END__
 
 =head1 NAME
 
-Stenciller::Renderer - A role for plugins to consume
+Stenciller::Renderer - A role for transformer plugins to consume
 
 =head1 VERSION
 
-Version 0.1004, released 2015-01-15.
+Version 0.1005, released 2015-01-16.
 
 =head1 SYNOPSIS
 
-    package Stenciller::Plugin::MyNewRenderer;
+    package Some::Place::MyNewRenderer;
 
     use Moose;
     with 'Stenciller::Renderer';
@@ -44,15 +39,13 @@ Version 0.1004, released 2015-01-15.
 
 =head1 DESCRIPTION
 
-This is the role that all L<Stenciller> plugins must consume. It requires a C<render> method to be implemented.
+This is the role that everything that renders something that a L<Stenciller::Transformer> plugin has transformed must consume. It requires a C<render> method to be implemented.
 
 
 
 =head1 ATTRIBUTES
 
-=head2 stenciller
-
-The L<Stenciller> object is passed automatically to plugins.
+Attributes can differ between consumers.
 
 =head1 SOURCE
 
