@@ -3,7 +3,7 @@ use warnings;
 
 use Moops;
 
-our $VERSION = '0.1004'; # VERSION
+# VERSION
 # PODNAME: Types::Stenciller
 # ABSTRACT: Types for Stenciller
 
@@ -11,8 +11,6 @@ library Types::Stenciller
 
 extends Types::Standard, Types::Path::Tiny
 
-declares Stencil, Renderer, Stenciller
-
 {
 
     class_type Stenciller => { class => 'Stenciller' };
@@ -34,7 +32,7 @@ Types::Stenciller - Types for Stenciller
 
 =head1 VERSION
 
-Version 0.1004, released 2015-01-15.
+Version 0.1005, released 2015-01-16.
 
 =head1 SYNOPSIS
 
